@@ -1,11 +1,14 @@
 use std::path::PathBuf;
+use chrono::Local;
+
+use crate::currency::Currency;
 
 use super::csv;
 use super::portfolio::{self, Portfolio};
 use super::interaction;
 
 pub fn add (file_name: Option<PathBuf>) -> Result<(), String> {
-    let (portfolio, path) = portfolio::get_portfolio_interactively(file_name)?;
+    let (portfolio, path) = portfolio::get_or_create_portfolio_interactively(file_name)?;
     if let Some(mut p) = portfolio {
         update_categories(&mut p);
         csv::save_portfolio(&path, p)?;
@@ -31,9 +34,17 @@ fn create_new_portfolio(path: PathBuf) {
 }
 
 fn update_categories(portfolio: &mut Portfolio) {
-    for (category, current_amount) in portfolio.data_mut() {
-        **current_amount = interaction::ask_for_input(&format!("Amount for {}", category), validate_amount);
-    }
+    let date = Local::now();
+    let data = portfolio.categories()
+        .map(|category| {
+            let default_value = portfolio.get_latest_value(category);
+            let input = interaction::Input::new(format!("Amount for {}", category), validate_amount).default_value(default_value.map(|c| c.0));
+            input.ask_for_input().unwrap()
+        })
+        .map(|amount| Currency(amount))
+        .collect::<Vec<Currency>>();
+
+    portfolio.set_data_for_date(date, data);
 }
 
 
